@@ -12,7 +12,7 @@ import traceback
 
 class CallHub:
     API_LIMIT = {
-        "GENERAL": {"calls": 18, "period": 1},
+        "GENERAL": {"calls": 13, "period": 1},
         "BULK_CREATE": {"calls": 1, "period": 70},
     }
 
@@ -30,11 +30,11 @@ class CallHub:
             rate_limit (``dict``, optional): Enabled by default with settings that respect callhub's API limits.
                 Setting this to false disables ratelimiting, or you can set your own limits by following the example
                 below. Please don't abuse! :)
-                >>> callhub = CallHub(rate_limit={"GENERAL": {"calls": 18, "period": 1},
+                >>> callhub = CallHub(rate_limit={"GENERAL": {"calls": 13, "period": 1},
                 >>>                               "BULK_CREATE": {"calls": 1, "period": 70}})
                 - Default limits bulk_create to 1 per 70 seconds (CallHub states their limit is every 60s but in
                   practice a delay of 60s exactly can trip their rate limiter anyways)
-                - Default limits all other API requests to 18 per second (CallHub support states their limit is 20/s but
+                - Default limits all other API requests to 13 per second (CallHub support states their limit is 20/s but
                   this plays it on the safe side, because other rate limiters seem a little sensitive)
         """
         self.session = FuturesSession(max_workers=43)
@@ -257,7 +257,7 @@ class CallHub:
         paged_data = paged_data[:limit]
         return paged_data
 
-    def _handle_requests(self, requests_list, aggregate_json_value=None):
+    def _handle_requests(self, requests_list, aggregate_json_value=None, retry=False, current_retry_count=0):
         """
         Internal function. Executes a list of requests in batches, asynchronously. Allows fast execution of many reqs.
         >>> requests_list = [{"func": session.get,
@@ -292,10 +292,15 @@ class CallHub:
                         responses.append(response)
 
                     except RuntimeError as api_except:
-                        errors.append(api_except)
+                        errors.append((requests_list[i], api_except))
 
                 requests_awaiting_response = []
 
+        if errors and retry and current_retry_count < 1:
+            failed_requests = [error[0] for error in errors]
+            new_responses, errors = self._handle_requests(failed_requests, retry=True, current_retry_count=current_retry_count+1)
+            responses = responses + new_responses
+
         return responses, errors
 
     def get_dnc_lists(self):
@@ -356,7 +361,7 @@ class CallHub:
                              "func_params": {"url": url, "data":data},
                              "expected_status": 201})
 
-        responses, errors = self._handle_requests(requests)
+        responses, errors = self._handle_requests(requests, retry=True)
         dnc_records = [request.json() for request in responses]
         results = self.pretty_format_dnc_data(dnc_records)
         return results, errors
